# katcp-python

[![Doc Status](https://readthedocs.org/projects/katcp-python/badge/?version=latest)](http://katcp-python.readthedocs.io/en/latest)
[![PyPI Version](https://img.shields.io/pypi/v/katcp.svg)](https://pypi.python.org/pypi/katcp)
[![Python Versions](https://img.shields.io/pypi/pyversions/katcp.svg)](https://pypi.python.org/pypi/katcp/)

Python client and server library for the Karoo Array Telescope Control
Protocol (KATCP).

For more info, see the doc directory in this
repository, or for online documentation of the latest release, [read the katcp-python documentation](http://katcp-python.readthedocs.io/en/latest/).
